"""Version constants for OpenSCAD installations."""

# renovate: datasource=github-releases depName=openscad/openscad
OPENSCAD_STABLE_VERSION = "2021.01"

# renovate: datasource=custom.openscad-snapshots depName=OpenSCAD versioning=loose
OPENSCAD_NIGHTLY_VERSION_WINDOWS = "2025.12.06"
# renovate: datasource=custom.openscad-snapshots depName=OpenSCAD versioning=loose
OPENSCAD_NIGHTLY_VERSION_LINUX = "2025.12.06.ai29830"
